pub struct ChatCompletionMessage {
pub role: String,
pub content: Option<String>,
pub tool_calls: Option<Vec<ToolCall>>,
pub reasoning_content: Option<String>,
}Expand description
Response message structure for ChatCompletionResponse (different from request ChatMessage)
Fields
role: Stringcontent: Option<String>tool_calls: Option<Vec<ToolCall>>reasoning_content: Option<String>Trait Implementations
Sourceimpl Clone for ChatCompletionMessage
impl Clone for ChatCompletionMessage
Sourcefn clone(&self) -> ChatCompletionMessage
fn clone(&self) -> ChatCompletionMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatCompletionMessage
impl Debug for ChatCompletionMessage
Sourceimpl<'de> Deserialize<'de> for ChatCompletionMessage
impl<'de> Deserialize<'de> for ChatCompletionMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChatCompletionMessage
impl JsonSchema for ChatCompletionMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChatCompletionMessage
impl RefUnwindSafe for ChatCompletionMessage
impl Send for ChatCompletionMessage
impl Sync for ChatCompletionMessage
impl Unpin for ChatCompletionMessage
impl UnsafeUnpin for ChatCompletionMessage
impl UnwindSafe for ChatCompletionMessage