pub struct ChatMessageDelta {
pub role: Option<String>,
pub content: Option<String>,
pub tool_calls: Option<Vec<ToolCallDelta>>,
pub reasoning_content: Option<String>,
}Expand description
Delta structure for streaming chat completion responses
Fields
role: Option<String>content: Option<String>tool_calls: Option<Vec<ToolCallDelta>>reasoning_content: Option<String>Trait Implementations
Sourceimpl Clone for ChatMessageDelta
impl Clone for ChatMessageDelta
Sourcefn clone(&self) -> ChatMessageDelta
fn clone(&self) -> ChatMessageDelta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatMessageDelta
impl Debug for ChatMessageDelta
Sourceimpl<'de> Deserialize<'de> for ChatMessageDelta
impl<'de> Deserialize<'de> for ChatMessageDelta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChatMessageDelta
impl JsonSchema for ChatMessageDelta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChatMessageDelta
impl RefUnwindSafe for ChatMessageDelta
impl Send for ChatMessageDelta
impl Sync for ChatMessageDelta
impl Unpin for ChatMessageDelta
impl UnsafeUnpin for ChatMessageDelta
impl UnwindSafe for ChatMessageDelta