pub struct ChatStreamChoice {
pub index: u32,
pub delta: ChatMessageDelta,
pub logprobs: Option<ChatLogProbs>,
pub finish_reason: Option<String>,
pub matched_stop: Option<Value>,
}Fields
index: u32delta: ChatMessageDeltalogprobs: Option<ChatLogProbs>finish_reason: Option<String>matched_stop: Option<Value>Trait Implementations
Sourceimpl Clone for ChatStreamChoice
impl Clone for ChatStreamChoice
Sourcefn clone(&self) -> ChatStreamChoice
fn clone(&self) -> ChatStreamChoice
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatStreamChoice
impl Debug for ChatStreamChoice
Sourceimpl<'de> Deserialize<'de> for ChatStreamChoice
impl<'de> Deserialize<'de> for ChatStreamChoice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChatStreamChoice
impl JsonSchema for ChatStreamChoice
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChatStreamChoice
impl RefUnwindSafe for ChatStreamChoice
impl Send for ChatStreamChoice
impl Sync for ChatStreamChoice
impl Unpin for ChatStreamChoice
impl UnsafeUnpin for ChatStreamChoice
impl UnwindSafe for ChatStreamChoice