pub struct ChatLogProbsContent {
pub token: String,
pub logprob: f32,
pub bytes: Option<Vec<u8>>,
pub top_logprobs: Vec<TopLogProb>,
}Fields
token: Stringlogprob: f32bytes: Option<Vec<u8>>top_logprobs: Vec<TopLogProb>Trait Implementations
Sourceimpl Clone for ChatLogProbsContent
impl Clone for ChatLogProbsContent
Sourcefn clone(&self) -> ChatLogProbsContent
fn clone(&self) -> ChatLogProbsContent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatLogProbsContent
impl Debug for ChatLogProbsContent
Sourceimpl<'de> Deserialize<'de> for ChatLogProbsContent
impl<'de> Deserialize<'de> for ChatLogProbsContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChatLogProbsContent
impl JsonSchema for ChatLogProbsContent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChatLogProbsContent
impl RefUnwindSafe for ChatLogProbsContent
impl Send for ChatLogProbsContent
impl Sync for ChatLogProbsContent
impl Unpin for ChatLogProbsContent
impl UnsafeUnpin for ChatLogProbsContent
impl UnwindSafe for ChatLogProbsContent