pub struct CompletionTokensDetails {
pub reasoning_tokens: Option<u32>,
pub accepted_prediction_tokens: Option<u32>,
pub rejected_prediction_tokens: Option<u32>,
}Fields
reasoning_tokens: Option<u32>accepted_prediction_tokens: Option<u32>rejected_prediction_tokens: Option<u32>Trait Implementations
Sourceimpl Clone for CompletionTokensDetails
impl Clone for CompletionTokensDetails
Sourcefn clone(&self) -> CompletionTokensDetails
fn clone(&self) -> CompletionTokensDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompletionTokensDetails
impl Debug for CompletionTokensDetails
Sourceimpl<'de> Deserialize<'de> for CompletionTokensDetails
impl<'de> Deserialize<'de> for CompletionTokensDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompletionTokensDetails
impl JsonSchema for CompletionTokensDetails
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CompletionTokensDetails
impl RefUnwindSafe for CompletionTokensDetails
impl Send for CompletionTokensDetails
impl Sync for CompletionTokensDetails
impl Unpin for CompletionTokensDetails
impl UnsafeUnpin for CompletionTokensDetails
impl UnwindSafe for CompletionTokensDetails