pub struct ContextManagementEntry {
pub type: ContextManagementType,
pub compact_threshold: Option<u32>,
}Expand description
A single entry in the Responses API context_management array.
Spec: each entry has type (currently only "compaction") and an optional
compact_threshold token count.
Fields
type: ContextManagementTypecompact_threshold: Option<u32>Trait Implementations
Sourceimpl Clone for ContextManagementEntry
impl Clone for ContextManagementEntry
Sourcefn clone(&self) -> ContextManagementEntry
fn clone(&self) -> ContextManagementEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContextManagementEntry
impl Debug for ContextManagementEntry
Sourceimpl<'de> Deserialize<'de> for ContextManagementEntry
impl<'de> Deserialize<'de> for ContextManagementEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContextManagementEntry
impl JsonSchema for ContextManagementEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContextManagementEntry
impl RefUnwindSafe for ContextManagementEntry
impl Send for ContextManagementEntry
impl Sync for ContextManagementEntry
impl Unpin for ContextManagementEntry
impl UnsafeUnpin for ContextManagementEntry
impl UnwindSafe for ContextManagementEntry