pub struct FunctionCallDelta {
pub name: Option<String>,
pub arguments: Option<String>,
}Fields
name: Option<String>arguments: Option<String>Trait Implementations
Sourceimpl Clone for FunctionCallDelta
impl Clone for FunctionCallDelta
Sourcefn clone(&self) -> FunctionCallDelta
fn clone(&self) -> FunctionCallDelta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionCallDelta
impl Debug for FunctionCallDelta
Sourceimpl<'de> Deserialize<'de> for FunctionCallDelta
impl<'de> Deserialize<'de> for FunctionCallDelta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionCallDelta
impl JsonSchema for FunctionCallDelta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionCallDelta
impl RefUnwindSafe for FunctionCallDelta
impl Send for FunctionCallDelta
impl Sync for FunctionCallDelta
impl Unpin for FunctionCallDelta
impl UnsafeUnpin for FunctionCallDelta
impl UnwindSafe for FunctionCallDelta