pub struct FunctionCallResponse {
pub name: String,
pub arguments: Option<String>,
}Fields
name: Stringarguments: Option<String>Trait Implementations
Sourceimpl Clone for FunctionCallResponse
impl Clone for FunctionCallResponse
Sourcefn clone(&self) -> FunctionCallResponse
fn clone(&self) -> FunctionCallResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionCallResponse
impl Debug for FunctionCallResponse
Sourceimpl<'de> Deserialize<'de> for FunctionCallResponse
impl<'de> Deserialize<'de> for FunctionCallResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionCallResponse
impl JsonSchema for FunctionCallResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionCallResponse
impl RefUnwindSafe for FunctionCallResponse
impl Send for FunctionCallResponse
impl Sync for FunctionCallResponse
impl Unpin for FunctionCallResponse
impl UnsafeUnpin for FunctionCallResponse
impl UnwindSafe for FunctionCallResponse