pub struct JsonSchemaFormat {
pub name: String,
pub schema: Value,
pub strict: Option<bool>,
}Fields
name: Stringschema: Valuestrict: Option<bool>Trait Implementations
Sourceimpl Clone for JsonSchemaFormat
impl Clone for JsonSchemaFormat
Sourcefn clone(&self) -> JsonSchemaFormat
fn clone(&self) -> JsonSchemaFormat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonSchemaFormat
impl Debug for JsonSchemaFormat
Sourceimpl<'de> Deserialize<'de> for JsonSchemaFormat
impl<'de> Deserialize<'de> for JsonSchemaFormat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JsonSchemaFormat
impl JsonSchema for JsonSchemaFormat
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for JsonSchemaFormat
impl RefUnwindSafe for JsonSchemaFormat
impl Send for JsonSchemaFormat
impl Sync for JsonSchemaFormat
impl Unpin for JsonSchemaFormat
impl UnsafeUnpin for JsonSchemaFormat
impl UnwindSafe for JsonSchemaFormat