pub struct Redacted(pub String);Tuple Fields
0: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Redacted
impl<'de> Deserialize<'de> for Redacted
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Redacted
impl JsonSchema for Redacted
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Redacted
impl RefUnwindSafe for Redacted
impl Send for Redacted
impl Sync for Redacted
impl Unpin for Redacted
impl UnsafeUnpin for Redacted
impl UnwindSafe for Redacted