pub struct ResponsePrompt {
pub id: String,
pub variables: Option<HashMap<String, PromptVariable>>,
pub version: Option<String>,
}Expand description
Reference to a prompt template and its variables.
Fields
id: Stringvariables: Option<HashMap<String, PromptVariable>>version: Option<String>Trait Implementations
Sourceimpl Clone for ResponsePrompt
impl Clone for ResponsePrompt
Sourcefn clone(&self) -> ResponsePrompt
fn clone(&self) -> ResponsePrompt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponsePrompt
impl Debug for ResponsePrompt
Sourceimpl<'de> Deserialize<'de> for ResponsePrompt
impl<'de> Deserialize<'de> for ResponsePrompt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResponsePrompt
impl JsonSchema for ResponsePrompt
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResponsePrompt
impl RefUnwindSafe for ResponsePrompt
impl Send for ResponsePrompt
impl Sync for ResponsePrompt
impl Unpin for ResponsePrompt
impl UnsafeUnpin for ResponsePrompt
impl UnwindSafe for ResponsePrompt