pub struct ToolCallDelta {
pub index: u32,
pub id: Option<String>,
pub tool_type: Option<String>,
pub function: Option<FunctionCallDelta>,
}Fields
index: u32id: Option<String>tool_type: Option<String>function: Option<FunctionCallDelta>Trait Implementations
Sourceimpl Clone for ToolCallDelta
impl Clone for ToolCallDelta
Sourcefn clone(&self) -> ToolCallDelta
fn clone(&self) -> ToolCallDelta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolCallDelta
impl Debug for ToolCallDelta
Sourceimpl<'de> Deserialize<'de> for ToolCallDelta
impl<'de> Deserialize<'de> for ToolCallDelta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolCallDelta
impl JsonSchema for ToolCallDelta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolCallDelta
impl RefUnwindSafe for ToolCallDelta
impl Send for ToolCallDelta
impl Sync for ToolCallDelta
impl Unpin for ToolCallDelta
impl UnsafeUnpin for ToolCallDelta
impl UnwindSafe for ToolCallDelta