pub struct TopLogProb {
pub token: String,
pub logprob: f32,
pub bytes: Option<Vec<u8>>,
}Fields
token: Stringlogprob: f32bytes: Option<Vec<u8>>Trait Implementations
Sourceimpl Clone for TopLogProb
impl Clone for TopLogProb
Sourcefn clone(&self) -> TopLogProb
fn clone(&self) -> TopLogProb
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TopLogProb
impl Debug for TopLogProb
Sourceimpl<'de> Deserialize<'de> for TopLogProb
impl<'de> Deserialize<'de> for TopLogProb
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TopLogProb
impl JsonSchema for TopLogProb
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TopLogProb
impl RefUnwindSafe for TopLogProb
impl Send for TopLogProb
impl Sync for TopLogProb
impl Unpin for TopLogProb
impl UnsafeUnpin for TopLogProb
impl UnwindSafe for TopLogProb