pub struct CompletionStreamChoice {
pub text: String,
pub index: u32,
pub logprobs: Option<LogProbs>,
pub finish_reason: Option<String>,
}Fields
text: Stringindex: u32logprobs: Option<LogProbs>finish_reason: Option<String>Trait Implementations
Sourceimpl Clone for CompletionStreamChoice
impl Clone for CompletionStreamChoice
Sourcefn clone(&self) -> CompletionStreamChoice
fn clone(&self) -> CompletionStreamChoice
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompletionStreamChoice
impl Debug for CompletionStreamChoice
Sourceimpl<'de> Deserialize<'de> for CompletionStreamChoice
impl<'de> Deserialize<'de> for CompletionStreamChoice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompletionStreamChoice
impl JsonSchema for CompletionStreamChoice
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CompletionStreamChoice
impl RefUnwindSafe for CompletionStreamChoice
impl Send for CompletionStreamChoice
impl Sync for CompletionStreamChoice
impl Unpin for CompletionStreamChoice
impl UnsafeUnpin for CompletionStreamChoice
impl UnwindSafe for CompletionStreamChoice