pub struct CompletionStreamResponse {
pub id: String,
pub object: String,
pub created: u64,
pub choices: Vec<CompletionStreamChoice>,
pub model: String,
pub system_fingerprint: Option<String>,
}Fields
id: Stringobject: Stringcreated: u64choices: Vec<CompletionStreamChoice>model: Stringsystem_fingerprint: Option<String>Trait Implementations
Sourceimpl Clone for CompletionStreamResponse
impl Clone for CompletionStreamResponse
Sourcefn clone(&self) -> CompletionStreamResponse
fn clone(&self) -> CompletionStreamResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompletionStreamResponse
impl Debug for CompletionStreamResponse
Sourceimpl<'de> Deserialize<'de> for CompletionStreamResponse
impl<'de> Deserialize<'de> for CompletionStreamResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompletionStreamResponse
impl JsonSchema for CompletionStreamResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CompletionStreamResponse
impl RefUnwindSafe for CompletionStreamResponse
impl Send for CompletionStreamResponse
impl Sync for CompletionStreamResponse
impl Unpin for CompletionStreamResponse
impl UnsafeUnpin for CompletionStreamResponse
impl UnwindSafe for CompletionStreamResponse