pub struct EmbeddingObject {
pub object: String,
pub embedding: Vec<f32>,
pub index: u32,
}Fields
object: Stringembedding: Vec<f32>index: u32Trait Implementations
Sourceimpl Clone for EmbeddingObject
impl Clone for EmbeddingObject
Sourcefn clone(&self) -> EmbeddingObject
fn clone(&self) -> EmbeddingObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmbeddingObject
impl Debug for EmbeddingObject
Sourceimpl<'de> Deserialize<'de> for EmbeddingObject
impl<'de> Deserialize<'de> for EmbeddingObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmbeddingObject
impl JsonSchema for EmbeddingObject
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmbeddingObject
impl RefUnwindSafe for EmbeddingObject
impl Send for EmbeddingObject
impl Sync for EmbeddingObject
impl Unpin for EmbeddingObject
impl UnsafeUnpin for EmbeddingObject
impl UnwindSafe for EmbeddingObject