pub struct EmbeddingResponse {
pub object: String,
pub data: Vec<EmbeddingObject>,
pub model: String,
pub usage: UsageInfo,
}Fields
object: Stringdata: Vec<EmbeddingObject>model: Stringusage: UsageInfoTrait Implementations
Sourceimpl Clone for EmbeddingResponse
impl Clone for EmbeddingResponse
Sourcefn clone(&self) -> EmbeddingResponse
fn clone(&self) -> EmbeddingResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmbeddingResponse
impl Debug for EmbeddingResponse
Sourceimpl<'de> Deserialize<'de> for EmbeddingResponse
impl<'de> Deserialize<'de> for EmbeddingResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmbeddingResponse
impl JsonSchema for EmbeddingResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmbeddingResponse
impl RefUnwindSafe for EmbeddingResponse
impl Send for EmbeddingResponse
impl Sync for EmbeddingResponse
impl Unpin for EmbeddingResponse
impl UnsafeUnpin for EmbeddingResponse
impl UnwindSafe for EmbeddingResponse