Module event_types

Module event_types 

Enums

CodeInterpreterCallEvent
Code interpreter call events for streaming
ContentPartEvent
Content part streaming events
FileSearchCallEvent
File search call events for streaming
FunctionCallEvent
Function call argument streaming events
ItemType
Item type discriminators used in output items
McpEvent
MCP (Model Context Protocol) call events
OutputItemEvent
Output item events for streaming
OutputTextEvent
Output text streaming events
RealtimeClientEvent
Realtime API client events sent over WebSocket/WebRTC/SIP connections.
RealtimeServerEvent
Realtime API server events received over WebSocket/WebRTC/SIP connections.
ResponseEvent
Response lifecycle events
WebSearchCallEvent
Web search call events for streaming

Functions

is_function_call_type
Check if an item type string is a function call variant
is_response_event
Check if an event type string matches any response lifecycle event