ItemType

Enum ItemType 

pub enum ItemType {
    FunctionCall,
    FunctionToolCall,
    McpCall,
    Function,
    McpListTools,
    WebSearchCall,
    CodeInterpreterCall,
    FileSearchCall,
    ImageGenerationCall,
}
Item type discriminators used in output items

Variants



FunctionCall



FunctionToolCall



McpCall



Function



McpListTools



WebSearchCall



CodeInterpreterCall



FileSearchCall



ImageGenerationCall

Implementations

Source

impl ItemType

pub const FUNCTION_CALL: &'static str = "function_call"

pub const FUNCTION_CALL_OUTPUT: &'static str = "function_call_output"

pub const FUNCTION_TOOL_CALL: &'static str = "function_tool_call"

pub const MCP_CALL: &'static str = "mcp_call"

pub const FUNCTION: &'static str = "function"

pub const MCP_LIST_TOOLS: &'static str = "mcp_list_tools"

pub const WEB_SEARCH_CALL: &'static str = "web_search_call"

pub const CODE_INTERPRETER_CALL: &'static str = "code_interpreter_call"

pub const FILE_SEARCH_CALL: &'static str = "file_search_call"

pub const IMAGE_GENERATION_CALL: &'static str = "image_generation_call"

pub const fn as_str(self) -> &'static str

pub const fn is_function_call(self) -> bool

Check if this is a function call variant (FunctionCall or FunctionToolCall)

pub const fn is_builtin_tool_call(self) -> bool

Check if this is a builtin tool call variant