pub struct GenerateMetaInfo {
pub id: String,
pub finish_reason: GenerateFinishReason,
pub prompt_tokens: u32,
pub weight_version: String,
pub input_token_logprobs: Option<Vec<Vec<Option<f64>>>>,
pub output_token_logprobs: Option<Vec<Vec<Option<f64>>>>,
pub completion_tokens: u32,
pub cached_tokens: u32,
pub e2e_latency: f64,
pub matched_stop: Option<Value>,
}Expand description
Metadata for a single generate completion
Fields
id: Stringfinish_reason: GenerateFinishReasonprompt_tokens: u32weight_version: Stringinput_token_logprobs: Option<Vec<Vec<Option<f64>>>>output_token_logprobs: Option<Vec<Vec<Option<f64>>>>completion_tokens: u32cached_tokens: u32e2e_latency: f64matched_stop: Option<Value>Trait Implementations
Sourceimpl Clone for GenerateMetaInfo
impl Clone for GenerateMetaInfo
Sourcefn clone(&self) -> GenerateMetaInfo
fn clone(&self) -> GenerateMetaInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenerateMetaInfo
impl Debug for GenerateMetaInfo
Sourceimpl<'de> Deserialize<'de> for GenerateMetaInfo
impl<'de> Deserialize<'de> for GenerateMetaInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GenerateMetaInfo
impl JsonSchema for GenerateMetaInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GenerateMetaInfo
impl RefUnwindSafe for GenerateMetaInfo
impl Send for GenerateMetaInfo
impl Sync for GenerateMetaInfo
impl Unpin for GenerateMetaInfo
impl UnsafeUnpin for GenerateMetaInfo
impl UnwindSafe for GenerateMetaInfo