pub struct GenerateResponse {
pub text: String,
pub output_ids: Vec<u32>,
pub meta_info: GenerateMetaInfo,
}Expand description
SGLang generate response (single completion or array for n>1)
Format for n=1:
{
"text": "...",
"output_ids": [...],
"meta_info": { ... }
}Format for n>1:
[
{"text": "...", "output_ids": [...], "meta_info": {...}},
{"text": "...", "output_ids": [...], "meta_info": {...}}
]Fields
text: Stringoutput_ids: Vec<u32>meta_info: GenerateMetaInfoTrait Implementations
Sourceimpl Clone for GenerateResponse
impl Clone for GenerateResponse
Sourcefn clone(&self) -> GenerateResponse
fn clone(&self) -> GenerateResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenerateResponse
impl Debug for GenerateResponse
Sourceimpl<'de> Deserialize<'de> for GenerateResponse
impl<'de> Deserialize<'de> for GenerateResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GenerateResponse
impl JsonSchema for GenerateResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GenerateResponse
impl RefUnwindSafe for GenerateResponse
impl Send for GenerateResponse
impl Sync for GenerateResponse
impl Unpin for GenerateResponse
impl UnsafeUnpin for GenerateResponse
impl UnwindSafe for GenerateResponse