Module interactions

Module interactions 

Structs

AllowedTools
Allowed tools configuration for MCP server
Annotation
Annotation for text content (citations)
CodeExecutionArguments
Arguments for code execution call
FileSearchResultData
Result data for file search result
GenerationConfig
GoogleSearchArguments
Arguments for Google search call
GoogleSearchResultData
Result data for Google search result
ImageConfig
Interaction
InteractionsCancelParams
Query parameters for POST /interactions/{id}/cancel
InteractionsDeleteParams
Query parameters for DELETE /interactions/{id}
InteractionsError
Error information in streaming events
InteractionsGetParams
Query parameters for GET /interactions/{id}
InteractionsRequest
InteractionsUsage
ModalityTokens
Token count by modality
SpeechConfig
ToolChoiceConfig
Turn
A turn in a conversation with role and content See: https://ai.google.dev/api/interactions-api#Resource:Turn
UrlContextArguments
Arguments for URL context call
UrlContextResultData
Result data for URL context result

Enums

AgentConfig
Agent configuration See: https://ai.google.dev/api/interactions-api#CreateInteraction-deep_research
AspectRatio
AudioMimeType
Supported audio MIME types
CodeExecutionLanguage
Supported languages for code execution
Content
Content is a polymorphic type representing different content types See: https://ai.google.dev/api/interactions-api#Resource:Content
Delta
Delta content for streaming updates See: https://ai.google.dev/api/interactions-api#ContentDelta
DocumentMimeType
Supported document MIME types
ImageMimeType
Supported image MIME types
ImageSize
InteractionStreamEvent
Server-Sent Event for Interactions API streaming See: https://ai.google.dev/api/interactions-api#streaming
InteractionsInput
Input can be Content, array of Content, array of Turn, or string See: https://ai.google.dev/api/interactions-api#request-body
InteractionsStatus
InteractionsTool
Interaction tool types See: https://ai.google.dev/api/interactions-api#Resource:Tool
MediaResolution
Image/video resolution options
ResponseModality
ThinkingLevel
ThinkingSummaries
ThoughtSummaryContent
Content types allowed in thought summary (text or image only)
ToolChoice
Tool choice can be a simple mode or a detailed config
ToolChoiceType
TurnContent
Turn content can be array of Content or a simple string
UrlContextStatus
Status of URL context retrieval
VideoMimeType
Supported video MIME types