pub enum MessageStreamEvent {
MessageStart {
message: Message,
},
MessageDelta {
delta: MessageDelta,
usage: MessageDeltaUsage,
},
MessageStop,
ContentBlockStart {
index: u32,
content_block: ContentBlock,
},
ContentBlockDelta {
index: u32,
delta: ContentBlockDelta,
},
ContentBlockStop {
index: u32,
},
Ping,
Error {
error: ErrorResponse,
},
}Expand description
Server-sent event wrapper
Variants
MessageStart
Start of a new message
MessageDelta
Update to a message
MessageStop
End of a message
ContentBlockStart
Start of a content block
ContentBlockDelta
Update to a content block
ContentBlockStop
End of a content block
Ping
Ping event (for keep-alive)
Error
Error event
Fields

error: ErrorResponseTrait Implementations
Sourceimpl Clone for MessageStreamEvent
impl Clone for MessageStreamEvent
Sourcefn clone(&self) -> MessageStreamEvent
fn clone(&self) -> MessageStreamEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageStreamEvent
impl Debug for MessageStreamEvent
Sourceimpl<'de> Deserialize<'de> for MessageStreamEvent
impl<'de> Deserialize<'de> for MessageStreamEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MessageStreamEvent
impl JsonSchema for MessageStreamEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MessageStreamEvent
impl RefUnwindSafe for MessageStreamEvent
impl Send for MessageStreamEvent
impl Sync for MessageStreamEvent
impl Unpin for MessageStreamEvent
impl UnsafeUnpin for MessageStreamEvent
impl UnwindSafe for MessageStreamEvent