pub struct BashCodeExecutionToolResultError {
pub error_type: String,
pub error_code: BashCodeExecutionToolResultErrorCode,
}Expand description
Bash code execution tool result error
Fields
error_type: Stringerror_code: BashCodeExecutionToolResultErrorCodeTrait Implementations
Sourceimpl Clone for BashCodeExecutionToolResultError
impl Clone for BashCodeExecutionToolResultError
Sourcefn clone(&self) -> BashCodeExecutionToolResultError
fn clone(&self) -> BashCodeExecutionToolResultError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BashCodeExecutionToolResultError
impl<'de> Deserialize<'de> for BashCodeExecutionToolResultError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BashCodeExecutionToolResultError
impl JsonSchema for BashCodeExecutionToolResultError
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BashCodeExecutionToolResultError
impl RefUnwindSafe for BashCodeExecutionToolResultError
impl Send for BashCodeExecutionToolResultError
impl Sync for BashCodeExecutionToolResultError
impl Unpin for BashCodeExecutionToolResultError
impl UnsafeUnpin for BashCodeExecutionToolResultError
impl UnwindSafe for BashCodeExecutionToolResultError