pub struct CacheCreation {
pub tokens_by_ttl: HashMap<String, u32>,
}Expand description
Cache creation breakdown
Fields
tokens_by_ttl: HashMap<String, u32>Trait Implementations
Sourceimpl Clone for CacheCreation
impl Clone for CacheCreation
Sourcefn clone(&self) -> CacheCreation
fn clone(&self) -> CacheCreation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CacheCreation
impl Debug for CacheCreation
Sourceimpl<'de> Deserialize<'de> for CacheCreation
impl<'de> Deserialize<'de> for CacheCreation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CacheCreation
impl JsonSchema for CacheCreation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CacheCreation
impl RefUnwindSafe for CacheCreation
impl Send for CacheCreation
impl Sync for CacheCreation
impl Unpin for CacheCreation
impl UnsafeUnpin for CacheCreation
impl UnwindSafe for CacheCreation