pub struct CitationsConfig {
pub enabled: Option<bool>,
}Expand description
Citations configuration
Fields
enabled: Option<bool>Trait Implementations
Sourceimpl Clone for CitationsConfig
impl Clone for CitationsConfig
Sourcefn clone(&self) -> CitationsConfig
fn clone(&self) -> CitationsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CitationsConfig
impl Debug for CitationsConfig
Sourceimpl<'de> Deserialize<'de> for CitationsConfig
impl<'de> Deserialize<'de> for CitationsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CitationsConfig
impl JsonSchema for CitationsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CitationsConfig
impl RefUnwindSafe for CitationsConfig
impl Send for CitationsConfig
impl Sync for CitationsConfig
impl Unpin for CitationsConfig
impl UnsafeUnpin for CitationsConfig
impl UnwindSafe for CitationsConfig