pub struct ContentBlockLocationCitation {
pub cited_text: String,
pub document_index: u32,
pub document_title: Option<String>,
pub start_block_index: u32,
pub end_block_index: u32,
}Expand description
Content block location citation
Fields
cited_text: Stringdocument_index: u32document_title: Option<String>start_block_index: u32end_block_index: u32Trait Implementations
Sourceimpl Clone for ContentBlockLocationCitation
impl Clone for ContentBlockLocationCitation
Sourcefn clone(&self) -> ContentBlockLocationCitation
fn clone(&self) -> ContentBlockLocationCitation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentBlockLocationCitation
impl Debug for ContentBlockLocationCitation
Sourceimpl<'de> Deserialize<'de> for ContentBlockLocationCitation
impl<'de> Deserialize<'de> for ContentBlockLocationCitation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContentBlockLocationCitation
impl JsonSchema for ContentBlockLocationCitation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContentBlockLocationCitation
impl RefUnwindSafe for ContentBlockLocationCitation
impl Send for ContentBlockLocationCitation
impl Sync for ContentBlockLocationCitation
impl Unpin for ContentBlockLocationCitation
impl UnsafeUnpin for ContentBlockLocationCitation
impl UnwindSafe for ContentBlockLocationCitation