pub struct ListModelsResponse {
pub data: Vec<ModelInfo>,
pub has_more: bool,
pub first_id: Option<String>,
pub last_id: Option<String>,
}Expand description
List of models response
Fields
data: Vec<ModelInfo>has_more: boolfirst_id: Option<String>last_id: Option<String>Trait Implementations
Sourceimpl Clone for ListModelsResponse
impl Clone for ListModelsResponse
Sourcefn clone(&self) -> ListModelsResponse
fn clone(&self) -> ListModelsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListModelsResponse
impl Debug for ListModelsResponse
Sourceimpl<'de> Deserialize<'de> for ListModelsResponse
impl<'de> Deserialize<'de> for ListModelsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListModelsResponse
impl JsonSchema for ListModelsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListModelsResponse
impl RefUnwindSafe for ListModelsResponse
impl Send for ListModelsResponse
impl Sync for ListModelsResponse
impl Unpin for ListModelsResponse
impl UnsafeUnpin for ListModelsResponse
impl UnwindSafe for ListModelsResponse