pub struct MessageDelta {
pub stop_reason: Option<StopReason>,
pub stop_sequence: Option<String>,
}Expand description
Message delta for streaming updates
Fields
stop_reason: Option<StopReason>stop_sequence: Option<String>Trait Implementations
Sourceimpl Clone for MessageDelta
impl Clone for MessageDelta
Sourcefn clone(&self) -> MessageDelta
fn clone(&self) -> MessageDelta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageDelta
impl Debug for MessageDelta
Sourceimpl<'de> Deserialize<'de> for MessageDelta
impl<'de> Deserialize<'de> for MessageDelta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MessageDelta
impl JsonSchema for MessageDelta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MessageDelta
impl RefUnwindSafe for MessageDelta
impl Send for MessageDelta
impl Sync for MessageDelta
impl Unpin for MessageDelta
impl UnsafeUnpin for MessageDelta
impl UnwindSafe for MessageDelta