pub struct ServerToolUsage {
pub web_search_requests: u32,
}Expand description
Server tool usage information
Fields
web_search_requests: u32Trait Implementations
Sourceimpl Clone for ServerToolUsage
impl Clone for ServerToolUsage
Sourcefn clone(&self) -> ServerToolUsage
fn clone(&self) -> ServerToolUsage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServerToolUsage
impl Debug for ServerToolUsage
Sourceimpl<'de> Deserialize<'de> for ServerToolUsage
impl<'de> Deserialize<'de> for ServerToolUsage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ServerToolUsage
impl JsonSchema for ServerToolUsage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ServerToolUsage
impl RefUnwindSafe for ServerToolUsage
impl Send for ServerToolUsage
impl Sync for ServerToolUsage
impl Unpin for ServerToolUsage
impl UnsafeUnpin for ServerToolUsage
impl UnwindSafe for ServerToolUsage