pub struct TextEditorCodeExecutionToolResultError {
pub error_type: String,
pub error_code: TextEditorCodeExecutionToolResultErrorCode,
}Expand description
Text editor code execution tool result error
Fields
error_type: Stringerror_code: TextEditorCodeExecutionToolResultErrorCodeTrait Implementations
Sourceimpl Clone for TextEditorCodeExecutionToolResultError
impl Clone for TextEditorCodeExecutionToolResultError
Sourcefn clone(&self) -> TextEditorCodeExecutionToolResultError
fn clone(&self) -> TextEditorCodeExecutionToolResultError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TextEditorCodeExecutionToolResultError
impl<'de> Deserialize<'de> for TextEditorCodeExecutionToolResultError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TextEditorCodeExecutionToolResultError
impl JsonSchema for TextEditorCodeExecutionToolResultError
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TextEditorCodeExecutionToolResultError
impl RefUnwindSafe for TextEditorCodeExecutionToolResultError
impl Send for TextEditorCodeExecutionToolResultError
impl Sync for TextEditorCodeExecutionToolResultError
impl Unpin for TextEditorCodeExecutionToolResultError
impl UnsafeUnpin for TextEditorCodeExecutionToolResultError
impl UnwindSafe for TextEditorCodeExecutionToolResultError