pub struct TextEditorTool {
pub tool_type: String,
pub name: String,
pub cache_control: Option<CacheControl>,
}Expand description
Text editor tool for computer use
Fields
tool_type: Stringname: Stringcache_control: Option<CacheControl>Trait Implementations
Sourceimpl Clone for TextEditorTool
impl Clone for TextEditorTool
Sourcefn clone(&self) -> TextEditorTool
fn clone(&self) -> TextEditorTool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextEditorTool
impl Debug for TextEditorTool
Sourceimpl<'de> Deserialize<'de> for TextEditorTool
impl<'de> Deserialize<'de> for TextEditorTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TextEditorTool
impl JsonSchema for TextEditorTool
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TextEditorTool
impl RefUnwindSafe for TextEditorTool
impl Send for TextEditorTool
impl Sync for TextEditorTool
impl Unpin for TextEditorTool
impl UnsafeUnpin for TextEditorTool
impl UnwindSafe for TextEditorTool