pub struct Usage {
pub input_tokens: u32,
pub output_tokens: u32,
pub cache_creation_input_tokens: Option<u32>,
pub cache_read_input_tokens: Option<u32>,
pub cache_creation: Option<CacheCreation>,
pub server_tool_use: Option<ServerToolUsage>,
pub service_tier: Option<String>,
}Expand description
Billing and rate-limit usage
Fields
input_tokens: u32The number of input tokens used
output_tokens: u32The number of output tokens used
cache_creation_input_tokens: Option<u32>The number of input tokens used to create the cache entry
cache_read_input_tokens: Option<u32>The number of input tokens read from the cache
cache_creation: Option<CacheCreation>Breakdown of cached tokens by TTL
server_tool_use: Option<ServerToolUsage>Server tool usage information
service_tier: Option<String>Service tier used for the request