pub struct WebFetchToolResultError {
pub error_type: String,
pub error_code: WebFetchToolResultErrorCode,
}Expand description
Web fetch tool result error
Fields
error_type: Stringerror_code: WebFetchToolResultErrorCodeTrait Implementations
Sourceimpl Clone for WebFetchToolResultError
impl Clone for WebFetchToolResultError
Sourcefn clone(&self) -> WebFetchToolResultError
fn clone(&self) -> WebFetchToolResultError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebFetchToolResultError
impl Debug for WebFetchToolResultError
Sourceimpl<'de> Deserialize<'de> for WebFetchToolResultError
impl<'de> Deserialize<'de> for WebFetchToolResultError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WebFetchToolResultError
impl JsonSchema for WebFetchToolResultError
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WebFetchToolResultError
impl RefUnwindSafe for WebFetchToolResultError
impl Send for WebFetchToolResultError
impl Sync for WebFetchToolResultError
impl Unpin for WebFetchToolResultError
impl UnsafeUnpin for WebFetchToolResultError
impl UnwindSafe for WebFetchToolResultError