pub struct WebSearchTool {
pub tool_type: String,
pub name: String,
pub allowed_domains: Option<Vec<String>>,
pub blocked_domains: Option<Vec<String>>,
pub max_uses: Option<u32>,
pub user_location: Option<UserLocation>,
pub cache_control: Option<CacheControl>,
}Expand description
Web search tool
Fields
tool_type: Stringname: Stringallowed_domains: Option<Vec<String>>blocked_domains: Option<Vec<String>>max_uses: Option<u32>user_location: Option<UserLocation>cache_control: Option<CacheControl>Trait Implementations
Sourceimpl Clone for WebSearchTool
impl Clone for WebSearchTool
Sourcefn clone(&self) -> WebSearchTool
fn clone(&self) -> WebSearchTool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebSearchTool
impl Debug for WebSearchTool
Sourceimpl<'de> Deserialize<'de> for WebSearchTool
impl<'de> Deserialize<'de> for WebSearchTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WebSearchTool
impl JsonSchema for WebSearchTool
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WebSearchTool
impl RefUnwindSafe for WebSearchTool
impl Send for WebSearchTool
impl Sync for WebSearchTool
impl Unpin for WebSearchTool
impl UnsafeUnpin for WebSearchTool
impl UnwindSafe for WebSearchTool