pub struct ParseFunctionCallRequest {
pub text: String,
pub tool_call_parser: String,
pub tools: Vec<Tool>,
}Expand description
Request to parse function calls from model output text.
Fields
text: StringThe text to parse for function calls.
tool_call_parser: StringThe parser type/name to use for parsing (e.g., “json”, “pythonic”).
tools: Vec<Tool>The list of available tools that the model can call.