Module realtime_session

Module realtime_session 

Structs

AudioTranscription
McpToolApprovalFilter
Granular approval filter specifying which tools always/never require approval.
McpToolFilter
A filter object to specify which tools are allowed.
NoiseReduction
RealtimeAudioConfig
RealtimeAudioConfigInput
RealtimeAudioConfigOutput
RealtimeSessionClientSecret
RealtimeSessionCreateRequest
RealtimeSessionCreateResponse
RealtimeTranscriptionSessionAudio
RealtimeTranscriptionSessionCreateRequest
RealtimeTranscriptionSessionCreateResponse
RealtimeTranscriptionSessionResponseAudio
RealtimeTranscriptionSessionResponseAudioConfigInput
RetentionRatioTruncation
TracingConfig
TruncationTokenLimits

Enums

ConnectorId
InfMarker
The literal string "inf". Used by MaxOutputTokens::Inf.
MaxOutputTokens
Integer token limit (1–4096) or "inf" for the maximum available tokens. Defaults to "inf".
McpAllowedTools
List of allowed tool names or a filter object.
McpToolApproval
Approval policy for MCP tools: a filter object or "always"/"never".
McpToolApprovalSetting
Single approval policy for all tools.
NoiseReductionType
OutputModality
RealtimeAudioFormats
RealtimeIncludeOption
RealtimeSessionType
The type of session. Always "realtime" for the Realtime API.
RealtimeToolChoiceConfig
"none", "auto", "required", or a specific function/MCP tool reference.
RealtimeToolsConfig
RealtimeTracingConfig
Either the string "auto" or a granular tracing configuration.
RealtimeTranscriptionSessionTurnDetection
Turn detection for transcription sessions. Only server_vad is currently supported.
RealtimeTranscriptionSessionType
The type of session. Always "transcription" for the Realtime API.
RealtimeTruncation
"auto", "disabled", or a retention ratio configuration.
RetentionRatioTruncationType
The retention ratio truncation type. Always "retention_ratio".
SemanticVadEagerness
Used only for semantic_vad mode. The eagerness of the model to respond. low will wait longer for the user to continue speaking, high will respond more quickly. auto is the default and is equivalent to medium. low, medium, and high have max timeouts of 8s, 4s, and 2s respectively.
ToolChoiceOptions
Controls which (if any) tool is called by the model.
TracingMode
The tracing mode. Always "auto".
TruncationMode
The truncation mode.
TurnDetection
Voice
Built-in voice name (e.g. “alloy”, “ash”) or custom voice reference.