pub struct CodeInterpreterTool {
pub container: Option<Value>,
}Fields
container: Option<Value>Trait Implementations
Sourceimpl Clone for CodeInterpreterTool
impl Clone for CodeInterpreterTool
Sourcefn clone(&self) -> CodeInterpreterTool
fn clone(&self) -> CodeInterpreterTool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeInterpreterTool
impl Debug for CodeInterpreterTool
Sourceimpl Default for CodeInterpreterTool
impl Default for CodeInterpreterTool
Sourcefn default() -> CodeInterpreterTool
fn default() -> CodeInterpreterTool
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CodeInterpreterTool
impl<'de> Deserialize<'de> for CodeInterpreterTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CodeInterpreterTool
impl JsonSchema for CodeInterpreterTool
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CodeInterpreterTool
impl RefUnwindSafe for CodeInterpreterTool
impl Send for CodeInterpreterTool
impl Sync for CodeInterpreterTool
impl Unpin for CodeInterpreterTool
impl UnsafeUnpin for CodeInterpreterTool
impl UnwindSafe for CodeInterpreterTool