pub struct ComputerCoordinate {
pub x: i32,
pub y: i32,
}Expand description
(x, y) coordinate pair used in Drag.path and Move/Click/Scroll actions.
Fields
x: i32y: i32Trait Implementations
Sourceimpl Clone for ComputerCoordinate
impl Clone for ComputerCoordinate
Sourcefn clone(&self) -> ComputerCoordinate
fn clone(&self) -> ComputerCoordinate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ComputerCoordinate
Sourceimpl Debug for ComputerCoordinate
impl Debug for ComputerCoordinate
Sourceimpl<'de> Deserialize<'de> for ComputerCoordinate
impl<'de> Deserialize<'de> for ComputerCoordinate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ComputerCoordinate
Sourceimpl JsonSchema for ComputerCoordinate
impl JsonSchema for ComputerCoordinate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ComputerCoordinate
impl PartialEq for ComputerCoordinate
Sourceimpl Serialize for ComputerCoordinate
impl Serialize for ComputerCoordinate
impl StructuralPartialEq for ComputerCoordinate