pub struct FileSearchRankingOptions {
pub hybrid_search: Option<HybridSearchOptions>,
pub ranker: Option<FileSearchRanker>,
pub score_threshold: Option<f64>,
}Expand description
Ranking options for file search results.
Fields
hybrid_search: Option<HybridSearchOptions>ranker: Option<FileSearchRanker>score_threshold: Option<f64>Trait Implementations
Sourceimpl Clone for FileSearchRankingOptions
impl Clone for FileSearchRankingOptions
Sourcefn clone(&self) -> FileSearchRankingOptions
fn clone(&self) -> FileSearchRankingOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileSearchRankingOptions
impl Debug for FileSearchRankingOptions
Sourceimpl<'de> Deserialize<'de> for FileSearchRankingOptions
impl<'de> Deserialize<'de> for FileSearchRankingOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FileSearchRankingOptions
impl JsonSchema for FileSearchRankingOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FileSearchRankingOptions
impl RefUnwindSafe for FileSearchRankingOptions
impl Send for FileSearchRankingOptions
impl Sync for FileSearchRankingOptions
impl Unpin for FileSearchRankingOptions
impl UnsafeUnpin for FileSearchRankingOptions
impl UnwindSafe for FileSearchRankingOptions