pub struct FileSearchResult {
pub file_id: String,
pub filename: String,
pub text: Option<String>,
pub score: Option<f32>,
pub attributes: Option<Value>,
}Expand description
A result from file search.
Fields
file_id: Stringfilename: Stringtext: Option<String>score: Option<f32>attributes: Option<Value>Trait Implementations
Sourceimpl Clone for FileSearchResult
impl Clone for FileSearchResult
Sourcefn clone(&self) -> FileSearchResult
fn clone(&self) -> FileSearchResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileSearchResult
impl Debug for FileSearchResult
Sourceimpl<'de> Deserialize<'de> for FileSearchResult
impl<'de> Deserialize<'de> for FileSearchResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FileSearchResult
impl JsonSchema for FileSearchResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FileSearchResult
impl RefUnwindSafe for FileSearchResult
impl Send for FileSearchResult
impl Sync for FileSearchResult
impl Unpin for FileSearchResult
impl UnsafeUnpin for FileSearchResult
impl UnwindSafe for FileSearchResult