pub struct HybridSearchOptions {
pub embedding_weight: Option<f64>,
pub text_weight: Option<f64>,
}Expand description
Weights combining embedding-based and text-based similarity.
Fields
embedding_weight: Option<f64>text_weight: Option<f64>Trait Implementations
Sourceimpl Clone for HybridSearchOptions
impl Clone for HybridSearchOptions
Sourcefn clone(&self) -> HybridSearchOptions
fn clone(&self) -> HybridSearchOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HybridSearchOptions
impl Debug for HybridSearchOptions
Sourceimpl<'de> Deserialize<'de> for HybridSearchOptions
impl<'de> Deserialize<'de> for HybridSearchOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HybridSearchOptions
impl JsonSchema for HybridSearchOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HybridSearchOptions
impl RefUnwindSafe for HybridSearchOptions
impl Send for HybridSearchOptions
impl Sync for HybridSearchOptions
impl Unpin for HybridSearchOptions
impl UnsafeUnpin for HybridSearchOptions
impl UnwindSafe for HybridSearchOptions