pub struct ImageInputMask {
pub file_id: Option<String>,
pub image_url: Option<String>,
}Expand description
Mask reference for image-generation edit calls. Spec: { file_id?, image_url? }.
Reuses the same upload conventions as P1 InputImage.
Fields
file_id: Option<String>image_url: Option<String>Trait Implementations
Sourceimpl Clone for ImageInputMask
impl Clone for ImageInputMask
Sourcefn clone(&self) -> ImageInputMask
fn clone(&self) -> ImageInputMask
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImageInputMask
impl Debug for ImageInputMask
Sourceimpl Default for ImageInputMask
impl Default for ImageInputMask
Sourcefn default() -> ImageInputMask
fn default() -> ImageInputMask
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ImageInputMask
impl<'de> Deserialize<'de> for ImageInputMask
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ImageInputMask
impl JsonSchema for ImageInputMask
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ImageInputMask
impl RefUnwindSafe for ImageInputMask
impl Send for ImageInputMask
impl Sync for ImageInputMask
impl Unpin for ImageInputMask
impl UnsafeUnpin for ImageInputMask
impl UnwindSafe for ImageInputMask