pub struct InputTokensDetails {
pub cached_tokens: u32,
}Fields
cached_tokens: u32Trait Implementations
Sourceimpl Clone for InputTokensDetails
impl Clone for InputTokensDetails
Sourcefn clone(&self) -> InputTokensDetails
fn clone(&self) -> InputTokensDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputTokensDetails
impl Debug for InputTokensDetails
Sourceimpl<'de> Deserialize<'de> for InputTokensDetails
impl<'de> Deserialize<'de> for InputTokensDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&PromptTokenUsageInfo> for InputTokensDetails
impl From<&PromptTokenUsageInfo> for InputTokensDetails
Sourcefn from(d: &PromptTokenUsageInfo) -> Self
fn from(d: &PromptTokenUsageInfo) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for InputTokensDetails
impl JsonSchema for InputTokensDetails
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InputTokensDetails
impl RefUnwindSafe for InputTokensDetails
impl Send for InputTokensDetails
impl Sync for InputTokensDetails
impl Unpin for InputTokensDetails
impl UnsafeUnpin for InputTokensDetails
impl UnwindSafe for InputTokensDetails