pub struct McpTool {
pub server_url: Option<String>,
pub authorization: Option<String>,
pub headers: Option<HashMap<String, String>>,
pub server_label: String,
pub server_description: Option<String>,
pub require_approval: Option<RequireApproval>,
pub allowed_tools: Option<Vec<String>>,
}Fields
server_url: Option<String>headers: Option<HashMap<String, String>>Custom headers to send to MCP server (from request payload, not HTTP headers)
server_label: Stringserver_description: Option<String>require_approval: Option<RequireApproval>Approval requirement configuration for MCP tools.
allowed_tools: Option<Vec<String>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for McpTool
impl<'de> Deserialize<'de> for McpTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpTool
impl JsonSchema for McpTool
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpTool
impl RefUnwindSafe for McpTool
impl Send for McpTool
impl Sync for McpTool
impl Unpin for McpTool
impl UnsafeUnpin for McpTool
impl UnwindSafe for McpTool