pub struct OutputTokensDetails {
pub reasoning_tokens: u32,
}Fields
reasoning_tokens: u32Trait Implementations
Sourceimpl Clone for OutputTokensDetails
impl Clone for OutputTokensDetails
Sourcefn clone(&self) -> OutputTokensDetails
fn clone(&self) -> OutputTokensDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputTokensDetails
impl Debug for OutputTokensDetails
Sourceimpl<'de> Deserialize<'de> for OutputTokensDetails
impl<'de> Deserialize<'de> for OutputTokensDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OutputTokensDetails
impl JsonSchema for OutputTokensDetails
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OutputTokensDetails
impl RefUnwindSafe for OutputTokensDetails
impl Send for OutputTokensDetails
impl Sync for OutputTokensDetails
impl Unpin for OutputTokensDetails
impl UnsafeUnpin for OutputTokensDetails
impl UnwindSafe for OutputTokensDetails