pub struct ReasoningInfo {
pub effort: Option<String>,
pub summary: Option<String>,
}Fields
effort: Option<String>summary: Option<String>Trait Implementations
Sourceimpl Clone for ReasoningInfo
impl Clone for ReasoningInfo
Sourcefn clone(&self) -> ReasoningInfo
fn clone(&self) -> ReasoningInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReasoningInfo
impl Debug for ReasoningInfo
Sourceimpl<'de> Deserialize<'de> for ReasoningInfo
impl<'de> Deserialize<'de> for ReasoningInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReasoningInfo
impl JsonSchema for ReasoningInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReasoningInfo
impl RefUnwindSafe for ReasoningInfo
impl Send for ReasoningInfo
impl Sync for ReasoningInfo
impl Unpin for ReasoningInfo
impl UnsafeUnpin for ReasoningInfo
impl UnwindSafe for ReasoningInfo