pub struct ResponseReasoningParam {
pub effort: Option<ReasoningEffort>,
pub summary: Option<ReasoningSummary>,
}Fields
effort: Option<ReasoningEffort>summary: Option<ReasoningSummary>Trait Implementations
Sourceimpl Clone for ResponseReasoningParam
impl Clone for ResponseReasoningParam
Sourcefn clone(&self) -> ResponseReasoningParam
fn clone(&self) -> ResponseReasoningParam
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseReasoningParam
impl Debug for ResponseReasoningParam
Sourceimpl<'de> Deserialize<'de> for ResponseReasoningParam
impl<'de> Deserialize<'de> for ResponseReasoningParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResponseReasoningParam
impl JsonSchema for ResponseReasoningParam
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResponseReasoningParam
impl RefUnwindSafe for ResponseReasoningParam
impl Send for ResponseReasoningParam
impl Sync for ResponseReasoningParam
impl Unpin for ResponseReasoningParam
impl UnsafeUnpin for ResponseReasoningParam
impl UnwindSafe for ResponseReasoningParam