pub struct ResponseToolEnvironment {}Trait Implementations
Sourceimpl Clone for ResponseToolEnvironment
impl Clone for ResponseToolEnvironment
Sourcefn clone(&self) -> ResponseToolEnvironment
fn clone(&self) -> ResponseToolEnvironment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseToolEnvironment
impl Debug for ResponseToolEnvironment
Sourceimpl Default for ResponseToolEnvironment
impl Default for ResponseToolEnvironment
Sourcefn default() -> ResponseToolEnvironment
fn default() -> ResponseToolEnvironment
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResponseToolEnvironment
impl<'de> Deserialize<'de> for ResponseToolEnvironment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResponseToolEnvironment
impl JsonSchema for ResponseToolEnvironment
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResponseToolEnvironment
impl RefUnwindSafe for ResponseToolEnvironment
impl Send for ResponseToolEnvironment
impl Sync for ResponseToolEnvironment
impl Unpin for ResponseToolEnvironment
impl UnsafeUnpin for ResponseToolEnvironment
impl UnwindSafe for ResponseToolEnvironment