pub struct ResponsesGetParams {
pub include: Vec<String>,
pub include_obfuscation: Option<bool>,
pub starting_after: Option<i64>,
pub stream: Option<bool>,
}Fields
include: Vec<String>include_obfuscation: Option<bool>starting_after: Option<i64>stream: Option<bool>Trait Implementations
Sourceimpl Clone for ResponsesGetParams
impl Clone for ResponsesGetParams
Sourcefn clone(&self) -> ResponsesGetParams
fn clone(&self) -> ResponsesGetParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponsesGetParams
impl Debug for ResponsesGetParams
Sourceimpl Default for ResponsesGetParams
impl Default for ResponsesGetParams
Sourcefn default() -> ResponsesGetParams
fn default() -> ResponsesGetParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResponsesGetParams
impl<'de> Deserialize<'de> for ResponsesGetParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResponsesGetParams
impl JsonSchema for ResponsesGetParams
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResponsesGetParams
impl RefUnwindSafe for ResponsesGetParams
impl Send for ResponsesGetParams
impl Sync for ResponsesGetParams
impl Unpin for ResponsesGetParams
impl UnsafeUnpin for ResponsesGetParams
impl UnwindSafe for ResponsesGetParams