pub struct WebSearchPreviewTool {
pub search_context_size: Option<String>,
pub user_location: Option<Value>,
}Fields
search_context_size: Option<String>user_location: Option<Value>Trait Implementations
Sourceimpl Clone for WebSearchPreviewTool
impl Clone for WebSearchPreviewTool
Sourcefn clone(&self) -> WebSearchPreviewTool
fn clone(&self) -> WebSearchPreviewTool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebSearchPreviewTool
impl Debug for WebSearchPreviewTool
Sourceimpl Default for WebSearchPreviewTool
impl Default for WebSearchPreviewTool
Sourcefn default() -> WebSearchPreviewTool
fn default() -> WebSearchPreviewTool
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WebSearchPreviewTool
impl<'de> Deserialize<'de> for WebSearchPreviewTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WebSearchPreviewTool
impl JsonSchema for WebSearchPreviewTool
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WebSearchPreviewTool
impl RefUnwindSafe for WebSearchPreviewTool
impl Send for WebSearchPreviewTool
impl Sync for WebSearchPreviewTool
impl Unpin for WebSearchPreviewTool
impl UnsafeUnpin for WebSearchPreviewTool
impl UnwindSafe for WebSearchPreviewTool