pub struct WebSearchSource {
pub source_type: String,
pub url: String,
}Expand description
A source returned from web search.
Fields
source_type: Stringurl: StringTrait Implementations
Sourceimpl Clone for WebSearchSource
impl Clone for WebSearchSource
Sourcefn clone(&self) -> WebSearchSource
fn clone(&self) -> WebSearchSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebSearchSource
impl Debug for WebSearchSource
Sourceimpl<'de> Deserialize<'de> for WebSearchSource
impl<'de> Deserialize<'de> for WebSearchSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WebSearchSource
impl JsonSchema for WebSearchSource
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WebSearchSource
impl RefUnwindSafe for WebSearchSource
impl Send for WebSearchSource
impl Sync for WebSearchSource
impl Unpin for WebSearchSource
impl UnsafeUnpin for WebSearchSource
impl UnwindSafe for WebSearchSource