pub struct SamplingParams {Show 19 fields
pub temperature: Option<f32>,
pub max_new_tokens: Option<u32>,
pub top_p: Option<f32>,
pub top_k: Option<i32>,
pub frequency_penalty: Option<f32>,
pub presence_penalty: Option<f32>,
pub repetition_penalty: Option<f32>,
pub stop: Option<StringOrArray>,
pub ignore_eos: Option<bool>,
pub skip_special_tokens: Option<bool>,
pub json_schema: Option<String>,
pub regex: Option<String>,
pub ebnf: Option<String>,
pub min_p: Option<f32>,
pub min_new_tokens: Option<u32>,
pub stop_token_ids: Option<Vec<u32>>,
pub no_stop_trim: Option<bool>,
pub n: Option<u32>,
pub sampling_seed: Option<u64>,
}Expand description
Sampling parameters for text generation
Fields
temperature: Option<f32>Temperature for sampling (must be >= 0.0, no upper limit)
max_new_tokens: Option<u32>Maximum number of new tokens to generate (must be >= 0)
top_p: Option<f32>Top-p nucleus sampling (0.0 < top_p <= 1.0)
top_k: Option<i32>Top-k sampling (-1 to disable, or >= 1)
frequency_penalty: Option<f32>presence_penalty: Option<f32>repetition_penalty: Option<f32>stop: Option<StringOrArray>ignore_eos: Option<bool>skip_special_tokens: Option<bool>json_schema: Option<String>regex: Option<String>ebnf: Option<String>min_p: Option<f32>min_new_tokens: Option<u32>Minimum number of new tokens (validated in schema function for cross-field check with max_new_tokens)
stop_token_ids: Option<Vec<u32>>no_stop_trim: Option<bool>n: Option<u32>sampling_seed: Option<u64>Trait Implementations
Sourceimpl Clone for SamplingParams
impl Clone for SamplingParams
Sourcefn clone(&self) -> SamplingParams
fn clone(&self) -> SamplingParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SamplingParams
impl Debug for SamplingParams
Sourceimpl Default for SamplingParams
impl Default for SamplingParams
Sourcefn default() -> SamplingParams
fn default() -> SamplingParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SamplingParams
impl<'de> Deserialize<'de> for SamplingParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SamplingParams
impl JsonSchema for SamplingParams
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SamplingParams
impl Serialize for SamplingParams
Sourceimpl Validate for SamplingParams
impl Validate for SamplingParams
Sourceimpl<'v_a> ValidateArgs<'v_a> for SamplingParams
impl<'v_a> ValidateArgs<'v_a> for SamplingParams