pub struct WorkerApiResponse {
pub success: bool,
pub message: String,
pub worker: Option<WorkerInfo>,
}Expand description
Generic API response
Fields
success: boolmessage: Stringworker: Option<WorkerInfo>Trait Implementations
Sourceimpl Clone for WorkerApiResponse
impl Clone for WorkerApiResponse
Sourcefn clone(&self) -> WorkerApiResponse
fn clone(&self) -> WorkerApiResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerApiResponse
impl Debug for WorkerApiResponse
Sourceimpl<'de> Deserialize<'de> for WorkerApiResponse
impl<'de> Deserialize<'de> for WorkerApiResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkerApiResponse
impl JsonSchema for WorkerApiResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkerApiResponse
impl RefUnwindSafe for WorkerApiResponse
impl Send for WorkerApiResponse
impl Sync for WorkerApiResponse
impl Unpin for WorkerApiResponse
impl UnsafeUnpin for WorkerApiResponse
impl UnwindSafe for WorkerApiResponse