pub struct WorkerErrorResponse {
pub error: String,
pub code: String,
}Expand description
Error response
Fields
error: Stringcode: StringTrait Implementations
Sourceimpl Clone for WorkerErrorResponse
impl Clone for WorkerErrorResponse
Sourcefn clone(&self) -> WorkerErrorResponse
fn clone(&self) -> WorkerErrorResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerErrorResponse
impl Debug for WorkerErrorResponse
Sourceimpl<'de> Deserialize<'de> for WorkerErrorResponse
impl<'de> Deserialize<'de> for WorkerErrorResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkerErrorResponse
impl JsonSchema for WorkerErrorResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkerErrorResponse
impl RefUnwindSafe for WorkerErrorResponse
impl Send for WorkerErrorResponse
impl Sync for WorkerErrorResponse
impl Unpin for WorkerErrorResponse
impl UnsafeUnpin for WorkerErrorResponse
impl UnwindSafe for WorkerErrorResponse