pub struct WorkerListResponse {
pub workers: Vec<WorkerInfo>,
pub total: usize,
pub stats: WorkerStats,
}Expand description
Worker list response
Fields
workers: Vec<WorkerInfo>total: usizestats: WorkerStatsTrait Implementations
Sourceimpl Clone for WorkerListResponse
impl Clone for WorkerListResponse
Sourcefn clone(&self) -> WorkerListResponse
fn clone(&self) -> WorkerListResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerListResponse
impl Debug for WorkerListResponse
Sourceimpl<'de> Deserialize<'de> for WorkerListResponse
impl<'de> Deserialize<'de> for WorkerListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkerListResponse
impl JsonSchema for WorkerListResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkerListResponse
impl RefUnwindSafe for WorkerListResponse
impl Send for WorkerListResponse
impl Sync for WorkerListResponse
impl Unpin for WorkerListResponse
impl UnsafeUnpin for WorkerListResponse
impl UnwindSafe for WorkerListResponse