pub struct WorkerStats {
pub total_workers: usize,
pub healthy_workers: usize,
pub total_models: usize,
pub total_load: usize,
pub by_type: WorkerTypeStats,
}Expand description
Worker statistics
Fields
total_workers: usizehealthy_workers: usizetotal_models: usizetotal_load: usizeby_type: WorkerTypeStatsTrait Implementations
Sourceimpl Clone for WorkerStats
impl Clone for WorkerStats
Sourcefn clone(&self) -> WorkerStats
fn clone(&self) -> WorkerStats
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerStats
impl Debug for WorkerStats
Sourceimpl<'de> Deserialize<'de> for WorkerStats
impl<'de> Deserialize<'de> for WorkerStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkerStats
impl JsonSchema for WorkerStats
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkerStats
impl RefUnwindSafe for WorkerStats
impl Send for WorkerStats
impl Sync for WorkerStats
impl Unpin for WorkerStats
impl UnsafeUnpin for WorkerStats
impl UnwindSafe for WorkerStats