pub struct WorkerTypeStats {
pub regular: usize,
pub prefill: usize,
pub decode: usize,
}Expand description
Worker statistics by type
Fields
regular: usizeprefill: usizedecode: usizeTrait Implementations
Sourceimpl Clone for WorkerTypeStats
impl Clone for WorkerTypeStats
Sourcefn clone(&self) -> WorkerTypeStats
fn clone(&self) -> WorkerTypeStats
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerTypeStats
impl Debug for WorkerTypeStats
Sourceimpl<'de> Deserialize<'de> for WorkerTypeStats
impl<'de> Deserialize<'de> for WorkerTypeStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkerTypeStats
impl JsonSchema for WorkerTypeStats
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkerTypeStats
impl RefUnwindSafe for WorkerTypeStats
impl Send for WorkerTypeStats
impl Sync for WorkerTypeStats
impl Unpin for WorkerTypeStats
impl UnsafeUnpin for WorkerTypeStats
impl UnwindSafe for WorkerTypeStats