Enums
- Code
Interpreter Call Event - Code interpreter call events for streaming
- Content
Part Event - Content part streaming events
- File
Search Call Event - File search call events for streaming
- Function
Call Event - Function call argument streaming events
- Item
Type - Item type discriminators used in output items
- McpEvent
- MCP (Model Context Protocol) call events
- Output
Item Event - Output item events for streaming
- Output
Text Event - Output text streaming events
- Realtime
Client Event - Realtime API client events sent over WebSocket/WebRTC/SIP connections.
- Realtime
Server Event - Realtime API server events received over WebSocket/WebRTC/SIP connections.
- Response
Event - Response lifecycle events
- WebSearch
Call Event - Web search call events for streaming
Functions
- is_
function_ call_ type - Check if an item type string is a function call variant
- is_
response_ event - Check if an event type string matches any response lifecycle event