Structs
- Allowed
Tools - Allowed tools configuration for MCP server
- Annotation
- Annotation for text content (citations)
- Code
Execution Arguments - Arguments for code execution call
- File
Search Result Data - Result data for file search result
- Generation
Config - Google
Search Arguments - Arguments for Google search call
- Google
Search Result Data - Result data for Google search result
- Image
Config - Interaction
- Interactions
Cancel Params - Query parameters for POST /interactions/{id}/cancel
- Interactions
Delete Params - Query parameters for DELETE /interactions/{id}
- Interactions
Error - Error information in streaming events
- Interactions
GetParams - Query parameters for GET /interactions/{id}
- Interactions
Request - Interactions
Usage - Modality
Tokens - Token count by modality
- Speech
Config - Tool
Choice Config - Turn
- A turn in a conversation with role and content See: https://ai.google.dev/api/interactions-api#Resource:Turn
- UrlContext
Arguments - Arguments for URL context call
- UrlContext
Result Data - Result data for URL context result
Enums
- Agent
Config - Agent configuration See: https://ai.google.dev/api/interactions-api#CreateInteraction-deep_research
- Aspect
Ratio - Audio
Mime Type - Supported audio MIME types
- Code
Execution Language - Supported languages for code execution
- Content
- Content is a polymorphic type representing different content types See: https://ai.google.dev/api/interactions-api#Resource:Content
- Delta
- Delta content for streaming updates See: https://ai.google.dev/api/interactions-api#ContentDelta
- Document
Mime Type - Supported document MIME types
- Image
Mime Type - Supported image MIME types
- Image
Size - Interaction
Stream Event - Server-Sent Event for Interactions API streaming See: https://ai.google.dev/api/interactions-api#streaming
- Interactions
Input - Input can be Content, array of Content, array of Turn, or string See: https://ai.google.dev/api/interactions-api#request-body
- Interactions
Status - Interactions
Tool - Interaction tool types See: https://ai.google.dev/api/interactions-api#Resource:Tool
- Media
Resolution - Image/video resolution options
- Response
Modality - Thinking
Level - Thinking
Summaries - Thought
Summary Content - Content types allowed in thought summary (text or image only)
- Tool
Choice - Tool choice can be a simple mode or a detailed config
- Tool
Choice Type - Turn
Content - Turn content can be array of Content or a simple string
- UrlContext
Status - Status of URL context retrieval
- Video
Mime Type - Supported video MIME types