ModelType

Struct ModelType 

pub struct ModelType(/* private fields */);

Implementations

Source

impl ModelType

pub const CHAT: Self

OpenAI Chat Completions API (/v1/chat/completions)

pub const COMPLETIONS: Self

OpenAI Completions API - legacy (/v1/completions)

pub const RESPONSES: Self

OpenAI Responses API (/v1/responses)

pub const EMBEDDINGS: Self

Embeddings API (/v1/embeddings)

pub const RERANK: Self

Rerank API (/v1/rerank)

pub const GENERATE: Self

SGLang Generate API (/generate)

pub const VISION: Self

Vision/multimodal support (images in input)

pub const TOOLS: Self

Tool/function calling support

pub const REASONING: Self

Reasoning/thinking support (e.g., o1, DeepSeek-R1)

pub const IMAGE_GEN: Self

Image generation (DALL-E, Sora, gpt-image)

pub const AUDIO: Self

Audio models (TTS, Whisper, realtime, transcribe)

pub const MODERATION: Self

Content moderation models

pub const LLM: Self

Standard LLM: chat + completions + responses + tools

pub const VISION_LLM: Self

Vision-capable LLM: LLM + vision

pub const REASONING_LLM: Self

Reasoning LLM: LLM + reasoning (e.g., o1, o3, DeepSeek-R1)

pub const FULL_LLM: Self

Full-featured LLM: all text generation capabilities

pub const EMBED_MODEL: Self

Embedding model only

pub const RERANK_MODEL: Self

Reranker model only

pub const IMAGE_MODEL: Self

Image generation model only (DALL-E, Sora, gpt-image)

pub const AUDIO_MODEL: Self

Audio model only (TTS, Whisper, realtime)

pub const MODERATION_MODEL: Self

Content moderation model only

Source

impl ModelType

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u16

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u16) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u16) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u16) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl ModelType

pub const fn iter(&self) -> Iter<ModelType>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ModelType>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl ModelType

pub fn supports_chat(self) -> bool

Check if this model type supports the chat completions endpoint

pub fn supports_completions(self) -> bool

Check if this model type supports the legacy completions endpoint

pub fn supports_responses(self) -> bool

Check if this model type supports the responses endpoint

pub fn supports_embeddings(self) -> bool

Check if this model type supports the embeddings endpoint

pub fn supports_rerank(self) -> bool

Check if this model type supports the rerank endpoint

pub fn supports_generate(self) -> bool

Check if this model type supports the generate endpoint

pub fn supports_vision(self) -> bool

Check if this model type supports vision/multimodal input

pub fn supports_tools(self) -> bool

Check if this model type supports tool/function calling

pub fn supports_reasoning(self) -> bool

Check if this model type supports reasoning/thinking

pub fn supports_image_gen(self) -> bool

Check if this model type supports image generation

pub fn supports_audio(self) -> bool

Check if this model type supports audio (TTS, Whisper, etc.)

pub fn supports_moderation(self) -> bool

Check if this model type supports content moderation

pub fn supports_endpoint(self, endpoint: Endpoint) -> bool

Check if this model type supports a given endpoint

pub fn as_capability_names(self) -> Vec<&'static str>

Convert to a list of supported capability names

pub fn is_llm(self) -> bool

Check if this is an LLM (supports at least chat)

pub fn is_embedding_model(self) -> bool

Check if this is an embedding model

pub fn is_reranker(self) -> bool

Check if this is a reranker model

pub fn is_image_model(self) -> bool

Check if this is an image generation model

pub fn is_audio_model(self) -> bool

Check if this is an audio model

pub fn is_moderation_model(self) -> bool

Check if this is a moderation model