Canonical worker types and identity.
This module defines the single source of truth for worker identity, type enums, and core configuration. These types are shared across API request/response boundaries and internal runtime state.
Structs
- Flush
Cache Result - Result from flush cache operations across workers
- Health
Check Config - Health check configuration shared across protocol and runtime layers.
- Health
Check Update - Partial health check config for PATCH-style updates.
- JobStatus
- Job status for async control plane operations
- Scheduler
Load Snapshot - Per-DP-rank load snapshot from a backend.
- Worker
ApiResponse - Generic API response
- Worker
Error Response - Error response
- Worker
Group Key - Composite key identifying a group of workers with the same characteristics.
- Worker
Info - Worker information for API responses.
- Worker
List Response - Worker list response
- Worker
Load Info - Individual worker load information
- Worker
Load Response - Full load response for a single worker across all DP ranks.
- Worker
Loads Result - Result from getting worker loads
- Worker
Spec - Core worker identity and configuration.
- Worker
Stats - Worker statistics
- Worker
Type Stats - Worker statistics by type
- Worker
Update Request - Worker update request
Enums
- Connection
Mode - Connection mode for worker communication.
- Provider
Type - Provider type for external API transformations.
- Runtime
Type - Runtime implementation type for workers.
- Worker
Models - Models configuration for a worker.
- Worker
Type - Worker type classification.